/*global chrome*/

// Called when the user clicks on the browser action
chrome.browserAction.onClicked.addListener(function(tab) {
  // Send a message to the active tab
  chrome.tabs.query({ active: true, currentWindow: true }, function(tabs) {
    var activeTab = tabs[0];
    chrome.tabs.sendMessage(activeTab.id, {
      message: "clicked_browser_action"
    });
  });
});

chrome.runtime.onMessage.addListener(function(request, sender, sendResponse) {
  if (request.contentScriptQuery === "searchBook") {
    var url =
      "https://www.googleapis.com/books/v1/volumes?q=" +
      encodeURIComponent(request.text) +
      "&key=AIzaSyAmZSwmEPwQiYH2LuBZWpZwyLGQByspktg";

    fetch(url)
      .then(response => {
        const { status } = response;

        if (status === 200) {
          return response.json();
        }
        return response;
      })
      .then(data => {
        if (!data || !data.items || !data.items.length) {
          sendResponse({
            error: { message: "No book was found, please try again." }
          });
        }

        const item = data.items[0];

        const book = {
          id: item.id,
          imgSrc: item.volumeInfo.imageLinks.thumbnail,
          description: item.volumeInfo.description,
          title: item.volumeInfo.title,
          authors: item.volumeInfo.authors
        };

        _gaq.push(['_trackEvent',
            'search',
            'search_book',
            request.text
        ]);

        sendResponse({ book: book });
      })
      .catch((error) => {
        _gaq.push(['_trackEvent',
            'search',
            'error',
            request.text,
            error
        ]);
        sendResponse({
          error: { message: "Ups.. Something went wrong, please try again" }
        });
      });
    return true; // Will respond asynchronously.
  }

  if(request.analytics) {
    _gaq.push(['_trackEvent',
        request.action,
        request.item_name,
        request.item_label
    ]);
  }

});

function handleSearchBookClick(info, tab) {
  chrome.tabs.query(
    {
      active: true,
      currentWindow: true
    },
    function(tabs) {
      _gaq.push(['_trackEvent',
        'click',
        'context_menu',
        'search_for_this_book'
      ]);
      chrome.tabs.sendMessage(tabs[0].id, {
        action: "showBookInfo"
      });
    }
  );
}

// function handleSaveQuote(info, tab) {
//   chrome.tabs.query(
//     {
//       active: true,
//       currentWindow: true
//     },
//     function(tabs) {
//       chrome.tabs.sendMessage(tabs[0].id, {
//         action: "saveQuote"
//       });
//     }
//   );
// }

chrome.contextMenus.create({
  title: "Search for this book",
  contexts: ["selection"],
  onclick: handleSearchBookClick
});

// chrome.contextMenus.create({
//   title: "Save quote",
//   contexts: ["selection"],
//   onclick: handleSaveQuote
// });

var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
ga.src = 'https://ssl.google-analytics.com/ga.js';
var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);

var _gaq = _gaq || [];
_gaq.push(['_setAccount', 'UA-130516844-1']);
_gaq.push(['_trackPageview']);
